import os.path, glob, drugrefapi_plugin

class drugref:
	def __init__(self, plugindir="plugins", name = "Drugref Service", version='1.0'):
		self._plugindir = plugindir
		self._plugins=[]
		self._services = {}
		self._provided = {}
		self._name = name
		self._version = version
		#scan the plugin directory for plugins
		for file in glob.glob(os.path.join(plugindir, "*.py")):
			print "Importing module:", file
			try:
				module = drugrefapi_plugin.import_path(file)
				self._plugins.append(module)
			except:
				self._log("Could not import %s" % file)
		for plugin in self._plugins:
			#try:
			module = plugin.drugrefplugin()
			#except:
			#	self._log("Could not instantiate plugin module %s" % file)
			#	continue
			name, version, provides, theplugin = module.register()
			self._services[name] = {'version':version, 'plugin': theplugin, 'provides':provides}
			#for each keyword (attribute) that plugin provides
			for provided in provides:
				try:
					#if there is already some service providing this attribute,
					#add the new service as potential provider to the list
					self._provided[provided].append(name)
				except:
					#else just create a new list of service providers for that new attribute
					self._provided[provided] = [name]
					
	def identify(self):
		return self._name
		
	def version(self):
		return self._version
					
	def list_available_services(self):
		return self._services.keys()
		
	def list_capabilities(self, service):
		return self._services[service]['provides']
					
	def fetch(self, attribute, key, services=[], feelinglucky=1):
		try:
			providers = self._provided[attribute]
		except:
			return {'Error': '"%s" not provided by any registered service' % attribute}
		results = {}
		#do we just want to check certain services in order of preference?
		if len(services)>0:
			myservices = services
		#or shall we check all available services?
		else:
			myservices = self._services.keys()
		#checxk all services we want to check for the requested attribute for the stated key
		for service in myservices:
			module = self._services[service]
			result = module.get(attribute, key)
			if len(result)>0:
				results[service] = result
				#if we want only the first hit from the preferred provider, nothing else to do:
				if feelinglucky:
					return results
		return results				
			 
			
	def _log(self, msg):
		print msg
		
if __name__ == "__main__":
	import sys, time, DocXMLRPCServer as rpcserver
	#import sys, time, SimpleXMLRPCServer as rpcserver
	#parse the command line:
	drugrefserver = drugref()
	try:
		server_url = sys.argv[1]
	except:
		server_url = "localhost"
	try:
		server_port = int(sys.argv[2])
	except:
		server_port = 8001

	print "Serving at port", server_port, server_url
	server=rpcserver.DocXMLRPCServer((server_url, server_port))
	
 	try:
 		#should work from Python 2.3 onwards
 		server.register_introspection_functions()
 	except:
 		print "Server not capable of introspection"
 
 	#try:
 	#	server.register_multicall_functions()
 	#except:
 	#	print "Server not capable of multicall functionality"

	server.register_function(drugrefserver.fetch)
	server.register_function(drugrefserver.list_available_services)
	server.register_function(drugrefserver.list_capabilities)
	server.register_function(drugrefserver.identify)
	server.register_function(drugrefserver.version)
	
	try:
		print "Server started on", time.asctime()
		server.serve_forever()
	except:
		#exit gracefully, release port
		del(server)
		print "Server closed on", time.asctime()
