import drugrefapi_base, pyPgSQL as dbapi
from copy import copy

class holbrook(drugrefapi_base.drugrefapi):
	def __init__(self, host='localhost', port=8123, database='drugref', user='drugref', pwd='drugref', backend='postgres'):
		drugrefapi_base.drugrefapi.__init__(self, host, port, database, user, pwd, backend)
		self._name = "Drug Interactions (Holbrook)"
		self._version = "0.1"
		self._funcs['checkinteractionsATC'] = self.checkinteractionsATC
		self.addfunc('checkinteractionsATC', '_search_interactions', ['interactions_byATC'])
		
	def legend(self, keyword):
		if keyword == 'effect':
			return {'a':'augments (no clinical effect)', 'A':'augments', 
			 'i':'inhibts  (no clinical effect)', 'I':'inhibits',
			 'n':'has no effect on', 'N':'has no effect on', ' ': 'unknown effect on'}
		elif keyword == 'significance':
			return {'1':'minor', '2':'moderate', '3':'major', ' ':'unknown'}
		elif keyword == 'evidence':
			return {'P':'poor', 'F':'fair', 'G':'good', ' ':'unknown'}
		 
	def checkinteractionsATC(self, druglist):
		idrugs = druglist
		interactions = []
		for drug in druglist:
                        idrugs = copy(druglist)
			idrugs.remove(drug)
			for idrug in idrugs:
				if idrug == drug:
					continue
				query = "select * from holbrook.interactions where affectingatc = %(affecting)s and affectedatc = %(affected)s"
				#print query % {'affecting':drug, 'affected':idrug}
				results = self._runquery(query, {'affecting':drug, 'affected':idrug})
				#print results
				for result in results:
					interaction = {}
					interaction['affectingatc'] = result['affectingatc']
					interaction['affectedatc'] = result['affectedatc']
					interaction['affectingdrug'] = result['affectingdrug']			
					interaction['affecteddrug'] = result['affecteddrug']
					interaction['significance'] = result['significance']
					interaction['effect'] = result['effect']
					interaction['evidence'] = result['evidence']
					interaction['comment'] = result['comment']			
					interactions.append(interaction)
		return interactions
		
	#def checkinteractionsNames(self, nameslist):
		


import drugrefapi_plugin
class drugrefplugin(drugrefapi_plugin.drugrefplugin):
	def __init__(self):
		drugrefapi_plugin.drugrefplugin.__init__(self)
		self._name = "Holbrook Drug Interactions"
		self._version = "1.0"
		self._plugin = holbrook(database='interactions')
		self._provides = self._plugin.list_capabilities()
		
		
if __name__ == "__main__":
	import sys, atcmapper
	if len(sys.argv)<2:
		print """USAGE: call this program with a space separated list of drug names
		(brand or generic or mixed) as parameters to get a list of their possible interactions"""
		sys.exit(2)
	api = holbrook(database='interactions')
	mapper = atcmapper.atcmapper()
	drugs = sys.argv[1:]
	codes = []
	#map all brand names, classes, generics etc. to ATC codes
	for drug in drugs:
		codes.extend(mapper.atc(drug))
	#get all intercations for the list of ATC codes
	interactions =  api.find('interactions_byATC', codes)
	#map returned codes to plain English
	effect = api.legend('effect')
	significance = api.legend('significance')
	evidence = api.legend('evidence')
	#display all found interacions
	for interaction in interactions:
		if interaction.has_key('Error'):
			print "ERROR:", interaction['Error']
			sys.exit(1)
		print "\n", interaction['affectingatc'], " (", interaction['affectingdrug'], ")", effect[interaction['effect']] , interaction['affectedatc'], " (", interaction['affecteddrug'] , ")", "\n\tSignificance of interaction is", significance[interaction['significance']], "\n\tEvidence is", evidence[interaction['evidence']]
		if len(interaction['comment'])>0:
			print "\n\tComment:", interaction['comment']