import drugrefapi_base

class MimsAbbrev(drugrefapi_base.drugrefapi):
	def __init__(self, host='localhost', port=8123, database='drugref', user='drugref', pwd='drugref', backend='postgres'):
		drugrefapi_base.drugrefapi.__init__(self, host, port, database, user, pwd, backend)
		
		self._name = "MIMS Abbrev"
		self._languages = ['eng']
		self._countries = ['AU']
		
		self._queries['find_products_and_generics'] = "select prodcode as pkey, tfproduct as name, 'bp' as type from mimsabb.proddat where tfproduct ilike %(_search_drugname)s union select gencode as pkey, tfgeneric as name, 'ge' as type from mimsabb.gendat where tfgeneric ilike %(_search_drugname)s order by name"

		self._queries['find_generics'] = "select gencode as pkey, tfgeneric as name, 'ge' as type from mimsabb.gendat where tfgeneric ilike %(_search_generic)s order by name"

		self._queries['find_branded'] = "select prodcode as pkey, tfproduct as name, 'bp' as type from mimsabb.proddat where tfproduct ilike %(_search_branded)s order by name"

		self._queries['find_generic_components'] = "select tfgeneric as name from mimsabb.gendat where gencode in (select gencode from mimsabb.gmdat where prodcode=%(_pkey_brandeddrug)s) order by name"

		self._queries['find_brands_containing_generic'] = "select prodcode as pkey, product as name from mimsabb.proddat where prodcode in (select prodcode from mimsabb.gmdat where gencode in (select gencode from mimsabb.gendat where tfgeneric ilike %(_search_generic)s)) order by name" 
		
		self._queries['product_formulation'] = "select form, brand as formulation_brandname, rx as prescription_only case when rx='Yes' then 't'else 'f', rx_text as prescription_only_narr, co as compositionwhere prodcode = %(searchexpr)s"

		self._queries['product_indications'] = "select ind as narrative from mimsabb.manxxdat where mancode = %(searchexpr)s"
		
		self._queries['narrativePI'] = "select tfproduct as product_name, pc as product_pregnancy_ADECcategory, use as product_indications_narr, ci as product_contraindications_narr, pr as product_precautions_narr, ar as product_adversereactions_narr, ir as product_interactions_narr, wa as product_warnings_narr, sportcode as product_sportcode_narr, s11 as AU_Victoria_S11, mancode as AU_MIMSAnnual_prodcode from mimsabb.proddat where prodcode = %(_pkey_brandeddrug)s"  
		
		self.addquery('find_products_and_generics', '_search_drugname', ['_found_drugnames'])
		self.addquery('find_generics', '_search_generic', ['_found_generics'])
		self.addquery('find_branded', '_search_branded', ['_found_branded']) 
		self.addquery('find_generic_components', '_pkey_brandeddrug', ['_found_genericcomponents'])
		self.addquery('find_brands_containing_generic', '_search_generic', ['_found_brands_for_generic'])
		self.addquery('narrativePI', '_pkey_brandeddrug', ['product_name', 'product_pregnancy_ADECcategory', 'product_indications_narr', 'product_contraindications_narr', 'product_precautions_narr', 'product_adversereactions_narr', 'product_interactions_narr', 'product_warnings_narr', 'product_sportcode_narr', 'AU_Victoria_S11', 'AU_MIMSAnnual_prodcode'])
		
		
	def htmlFullPI(self, id_brandname):
		result = self._runquery(self._queries['narrativePI'], {'_pkey_brandeddrug':id_brandname})
		if len(result) < 1:
			return ""
		htmltemplate = "<html><header>%(header)s</header><body>%(body)s</body></html>"
		html={}
		html['header'] = ''
		html['body'] = """<h1>%(product_name)s</h1>
		          <hr>
			  <i>Pregnancy Code:</i><b> %(product_pregnancy_ADECcategory)s </b>
			  <h2>Indications:</h2> %(product_indications_narr)s
			  <h2>Contraindications:</h2> %(product_contraindications_narr)s
			  <h2>Warnings:</h2> %(product_warnings_narr)s
			  <h2>Precautions:</h2>%(product_precautions_narr)s
			  <h2>Interactions:</h2>%(product_interactions_narr)s
			  <h2>Adverse Reactions:</h2>%(product_adversereactions_narr)s
			  <h2>Formulations:</h2>
			 """ % result[0]
		results = self._runquery("select * from mimsabb.formdat where prodcode = %(_pkey_brandeddrug)s order by formsort ", {'_pkey_brandeddrug':id_brandname})
		
		prodhtml = []
		for product in results:
			prodstr = """<hr>
			<b>%(brand)s : %(form)s - [%(rx_text)s]</b><br>
			%(co)s
			<p>%(da)s</p>
			""" % product
			prodhtml.append(prodstr)
		html['body'] += ' '.join(prodhtml)
		return htmltemplate % html
		
		
if __name__ == "__main__":
	import sys
	
	mims = MimsAbbrev(database='mims')
	
	print "Drugref adapter for '%s'has the following capabilities:" % mims.get_name()
	for capability in mims.list_capabilities():
		print capability
	#print "------------------------------------------------------------------------------"
	if len(sys.argv)!=2:
		print "Usage: drugrefapi_mimsabbrev.py <drug brand name>" 
	brandname = sys.argv[1]
	results = mims.find('_found_branded', brandname)
	#print results
	for drug in results:
		if drug.has_key('Error'):
			print 'Error:', drug['Error']
			continue
		print "Brandname found is", mims.get('product_name', drug['pkey'])
		print "Indications:", mims.get('product_indications_narr', drug['pkey'])
		generics = mims.find('_found_genericcomponents', drug['pkey'])
		for generic in generics:
			print "\tGeneric:", generic['name']
	
