import drugrefapi_base

class MimsAnnual(drugrefapi_base.drugrefapi):
	def __init__(self, host='localhost', port=8123, database='drugref', user='drugref', pwd='drugref', backend='postgres'):
		drugrefapi_base.drugrefapi.__init__(self, host, port, database, user, pwd, backend)
		
		self._name = "MIMS Annual"
		self._languages = ['eng']
		self._countries = ['AU']
		
		self._queries['find_products_and_generics'] = "select mancode as pkey, tfproduct as name, 'bp' as type from mimsannual.manxxdat where product ilike '%(_search_drugname)s%%' union select gencode as pkey, tfgeneric as name, 'ge' as type from mimsannual.genman where tfgeneric ilike '%(_search_drugname)s'"

		self._queries['find_generics'] = "select gencode as pkey, tfgeneric as name, 'ge' as type from mimsannual.genman where tfgeneric ilike %(_search_generic)s"

		self._queries['find_branded'] = "select mancode as pkey, tfproduct as name, 'bp' as type from mimsannual.manxxdat where tfproduct ilike %(_search_branded)s"

		self._queries['find_generic_components'] = "select tfgeneric as name, gencode as pkey from mimsannual.genman where gencode in (select gencode from mimsannual.gmman where mancode=%(_pkey_brandeddrug)s)"

		self._queries['find_brands_containing_generic'] = "select mancode as pkey, product as name from mimsannual.manxxdat where mancode in (select mancode from mimsannual.gmman where gencode in (select gencode from mimsannual.genman where tfgeneric ilike %(_search_generic)s))" 
		
		self._queries['product_appearance'] = "select description as product_appearance_nar, colour as product_colour, alpha as product_alpha, image as product_image from mimsannual.maniddat where mancode = %(_pkey_brandeddrug)s"
		
		self._queries['narrative_PI'] = "select tfproduct as product_name, co as product_composition_nar, des as product_description_nar, ac as product_actions_nar, ind as product_indications_nar, ci as product_contraindications_nar, wa as product_warnings_nar, pr as product_precautions_nar, ar as product_adverse_reactions_nar, ir as product_interactions_nar, od as product_overdosage_nar, da as product_dosageadministration_nar, du as product_usedirections_nar, prn as product_presentation_nar, str as product_storage_nar, ps as product_poisonsschedule, ref as product_approvaldate_nar from mimsannual.manxxdat where mancode = %(_pkey_brandeddrug)s"  
		
		self.addquery('find_products_and_generics', '_search_drugname', ['_found_drugnames']) 
		self.addquery('find_generic_components', '_pkey_brandeddrug', ['_found_genericcomponents'])
		self.addquery('find_generics', '_search_generic', ['_found_generics'])
		self.addquery('find_branded', '_search_branded', ['_found_branded'])
		self.addquery('find_brands_containing_generic', '_search_generic', ['_found_generics_in_brand'])
		self.addquery('narrative_PI', '_pkey_brandeddrug', ['product_name', 'product_composition_nar', 'product_description_nar', 'product_warnings_nar', 'product_precautions_nar', 'product_adverse_reactions_nar', 'product_interactions_nar', 'product_overdosage_nar', 'product_dosageadministration_nar', 'product_usedirections_nar',  'product_presentation_nar', 'product_storage_nar', 'product_poisonsschedule', 'product_approvaldate_nar'])
		

		
if __name__ == "__main__":
	import sys
	
	mims = MimsAnnual(database='mims')
	
	#print "Drugref adapter for '%s'has the following capabilities:" % mims.get_name()
	#for capability in mims.list_capabilities():
	#	print capability
	#print "------------------------------------------------------------------------------"
	brandname = sys.argv[1]
	results = mims.find('_found_branded', brandname)
	#print results
	for drug in results:
		if drug.has_key('Error'):
			print 'Error:', drug['Error']
			continue
		print "Brandname found is", mims.get('product_name', drug['pkey'])
		generics = mims.find('_found_genericcomponents', drug['pkey'])
		for generic in generics:
			print "\tGeneric:", generic['name']
	
		print mims.get('product_description_nar', drug['pkey'])
		#print mims.get('product_dosageadministration_nar', drug['pkey'])