import drugrefapi_base

class PBS(drugrefapi_base.drugrefapi):
	def __init__(self, host='localhost', port=8123, database='drugref', user='drugref', pwd='drugref', backend='postgres'):
		drugrefapi_base.drugrefapi.__init__(self, host, port, database, user, pwd, backend)
		
		self._name = "Australian PBS database"
		self._languages = ['eng']
		self._countries = ['AU']
		
		self._queries['find_products_and_generics'] = "select id as pkey, brandname as name, 'bp' as type from pbs.drug where brandname ilike %(_search_drugname)s union select id as pkey, drugname as name, 'ge' as type from pbs.drug where drugname ilike %(_search_drugname)s order by name"

		self._queries['find_generics'] = "select id as pkey, drugname as name, 'ge' as type from pbs.drug where drugname ilike %(_search_drugname)s order by name"

		self._queries['find_branded'] = "select id as pkey, brandname as name, 'bp' as type from pbs.drug where brandname ilike %(_search_drugname)s order by name"
	
		self._queries['find_prescribinginfo'] = "select brandname as name, 'bp' as type, formandstrength, packsize, maxquantity, numrepeats, brandpremium, thergrouppremium from pbs.drug where brandname ilike %(_search_drugname)s union select distinct on (drugname, formandstrength, packsize) drugname as name, 'ge' as type, formandstrength, packsize, maxquantity, numrepeats, brandpremium, thergrouppremium from pbs.drug where drugname ilike %(_search_drugname)s order by name"
			
		self._queries['find_companies'] = "select manufacturercode as pkey, manufacturername as company_name, streetaddress as company_address_narr, telephonenumber as company_phone, facsimilenumber as company_fax from pbs.mnfr where manufacturername ilike %(_search_companyname)s"
		
		self._queries['find_atccode'] = "select atccode as atc_code, atcmeaning as atc_text from pbs.atc where atcmeaning ilike %(_search_atctext)s"
		
		self._queries['find_drug'] = "select drugtypecode, atc, atctype, atcprint, pbscode, restrictionflag, cautionflag, noteflag, maxquantity, numrepeats, manufacturer, packsize, markupcode,dispensingfeecode, dangerousdrugfeecode, brandpremium, thergrouppremium, cwpricetopharmacist, cwdpricemaxqty, tgmpp, tgmdp, manpricetopharmacist, mandisppricemaxqty, maxrecvalsftynet, bioeqindicator,brandname, drugname, formandstrength from pbs.drug where drugname ilike %(_search_drug)s or brandname ilike %(_search_drug)s"
		
		self._queries['atc_text'] = "select atcmeaning as atc_text from pbs.atc where atccode = %(_pkey_atc)s"
		
		self._queries['pbsdrug'] = "select drugtypecode, atc, atctype, atcprint, pbscode, restrictionflag, cautionflag, noteflag, maxquantity, numrepeats, manufacturer, packsize, markupcode,dispensingfeecode, dangerousdrugfeecode, brandpremium, thergrouppremium, cwpricetopharmacist, cwdpricemaxqty, tgmpp, tgmdp, manpricetopharmacist, mandisppricemaxqty, maxrecvalsftynet, bioeqindicator,brandname, drugname, formandstrength from pbs.drug where id = %(_pkey_drug)s"
		
		self.addquery('find_products_and_generics', '_search_drugname', ['_found_drugnames'])
		self.addquery('find_generics', '_search_generic', ['_found_generics'])
		self.addquery('find_branded', '_search_branded', ['_found_branded'])
		self.addquery('find_prescribinginfo', '_search_drugname', ['_found_prescribinginfo']) 
		self.addquery('find_companies', '_search_companyname', ['_found_companies']) 
		self.addquery('find_atccode', '_search_atctext', ['_found_atccodes'])
		self.addquery('atc_text', '_pkey_atc', ['atc_text'])
		
if __name__ == "__main__":
	import sys
	
	pbs = PBS(database='pbs')
	
	#print "Drugref adapter for '%s'has the following capabilities:" % mims.get_name()
	#for capability in mims.list_capabilities():
	#	print capability
	#print "------------------------------------------------------------------------------"
	drugname = sys.argv[1]
	results = pbs.find('_found_atccodes', drugname)
	for drug in results:
		if drug.has_key('Error'):
			print 'Error:', drug['Error']
			continue
		print "Matching ATC codes for drug %s are:" % drug['atc_text'],
		print "\t", drug['atc_code'] 
		print pbs.get('atc_text', drug['atc_code'])
	